@@ -28,6 +28,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <string.h>
+#include <stdlib.h>
 
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
@@ -457,6 +458,8 @@ do_mount (GVfsBackend *backend,
   char *uri;
   int res;
   char *display_name;
+  const char *debug;
+  int debug_val;
   GMountSpec *smb_mount_spec;
   smbc_stat_fn smbc_stat;
 
@@ -470,7 +473,13 @@ do_mount (GVfsBackend *backend,
     }
   smbc_setOptionUserData (smb_context, backend);
 
-  smbc_setDebug (smb_context, 0);
+  debug = g_getenv ("GVFS_SMB_DEBUG");
+  if (debug)
+    debug_val = atoi (debug);
+  else
+    debug_val = 0;
+
+  smbc_setDebug (smb_context, debug_val);
   smbc_setFunctionAuthDataWithContext (smb_context, auth_callback);
   
   smbc_setFunctionAddCachedServer (smb_context, add_cached_server);
@@ -506,23 +515,6 @@ do_mount (GVfsBackend *backend,
 
   op_backend->smb_context = smb_context;
 
-  /* Translators: This is "<sharename> on <servername>" and is used as name for an SMB share */
-  display_name = g_strdup_printf (_("%s on %s"), op_backend->share, op_backend->server);
-  g_vfs_backend_set_display_name (backend, display_name);
-  g_free (display_name);
-  g_vfs_backend_set_icon_name (backend, "folder-remote");
-  
-  smb_mount_spec = g_mount_spec_new ("smb-share");
-  g_mount_spec_set (smb_mount_spec, "share", op_backend->share);
-  g_mount_spec_set (smb_mount_spec, "server", op_backend->server);
-  if (op_backend->user)
-    g_mount_spec_set (smb_mount_spec, "user", op_backend->user);
-  if (op_backend->domain)
-    g_mount_spec_set (smb_mount_spec, "domain", op_backend->domain);
-  
-  g_vfs_backend_set_mount_spec (backend, smb_mount_spec);
-  g_mount_spec_unref (smb_mount_spec);
-
   uri = create_smb_uri (op_backend->server, op_backend->share, NULL);
 
   op_backend->mount_source = mount_source;
@@ -559,6 +551,27 @@ do_mount (GVfsBackend *backend,
       return;
     }
 
+  /* Mount was successful */
+
+  /* Translators: This is "<sharename> on <servername>" and is used as name for an SMB share */
+  display_name = g_strdup_printf (_("%s on %s"), op_backend->share, op_backend->server);
+  g_vfs_backend_set_display_name (backend, display_name);
+  g_free (display_name);
+  g_vfs_backend_set_icon_name (backend, "folder-remote");
+
+  smb_mount_spec = g_mount_spec_new ("smb-share");
+  g_mount_spec_set (smb_mount_spec, "share", op_backend->share);
+  g_mount_spec_set (smb_mount_spec, "server", op_backend->server);
+  if (op_backend->last_user && strlen(op_backend->last_user) > 0)
+    {
+      g_mount_spec_set (smb_mount_spec, "user", op_backend->last_user);
+      if (op_backend->last_domain)
+        g_mount_spec_set (smb_mount_spec, "domain", op_backend->last_domain);
+    }
+
+  g_vfs_backend_set_mount_spec (backend, smb_mount_spec);
+  g_mount_spec_unref (smb_mount_spec);
+
   g_vfs_keyring_save_password (op_backend->last_user,
 			       op_backend->server,
 			       op_backend->last_domain,
